# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GroupPolicySetDefinitionArgs', 'GroupPolicySetDefinition']

@pulumi.input_type
class GroupPolicySetDefinitionArgs:
    def __init__(__self__, *,
                 display_name: pulumi.Input[_builtins.str],
                 management_group_id: pulumi.Input[_builtins.str],
                 policy_definition_references: pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs']]],
                 policy_type: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 metadata: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parameters: Optional[pulumi.Input[_builtins.str]] = None,
                 policy_definition_groups: Optional[pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionGroupArgs']]]] = None):
        """
        The set of arguments for constructing a GroupPolicySetDefinition resource.
        :param pulumi.Input[_builtins.str] display_name: The display name of this Policy Set Definition.
        :param pulumi.Input[_builtins.str] management_group_id: The ID of the Management Group where this Policy Set Definition should be created. Changing this forces a new Policy Set Definition to be created.
        :param pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs']]] policy_definition_references: One or more `policy_definition_reference` blocks as defined below.
        :param pulumi.Input[_builtins.str] policy_type: The Policy Set Definition type. Possible values are `BuiltIn`, `Custom`, `NotSpecified`, and `Static`. Changing this forces a new Policy Set Definition to be created.
        :param pulumi.Input[_builtins.str] description: The description of this Policy Set Definition.
        :param pulumi.Input[_builtins.str] metadata: The metadata for the Policy Set Definition in JSON format.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Policy Set Definition. Changing this forces a new Policy Set Definition to be created.
        :param pulumi.Input[_builtins.str] parameters: The parameters for the Policy Set Definition in JSON format. Reducing the number of parameters forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionGroupArgs']]] policy_definition_groups: One or more `policy_definition_group` blocks as defined below.
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "management_group_id", management_group_id)
        pulumi.set(__self__, "policy_definition_references", policy_definition_references)
        pulumi.set(__self__, "policy_type", policy_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if policy_definition_groups is not None:
            pulumi.set(__self__, "policy_definition_groups", policy_definition_groups)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[_builtins.str]:
        """
        The display name of this Policy Set Definition.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter(name="managementGroupId")
    def management_group_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Management Group where this Policy Set Definition should be created. Changing this forces a new Policy Set Definition to be created.
        """
        return pulumi.get(self, "management_group_id")

    @management_group_id.setter
    def management_group_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "management_group_id", value)

    @_builtins.property
    @pulumi.getter(name="policyDefinitionReferences")
    def policy_definition_references(self) -> pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs']]]:
        """
        One or more `policy_definition_reference` blocks as defined below.
        """
        return pulumi.get(self, "policy_definition_references")

    @policy_definition_references.setter
    def policy_definition_references(self, value: pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs']]]):
        pulumi.set(self, "policy_definition_references", value)

    @_builtins.property
    @pulumi.getter(name="policyType")
    def policy_type(self) -> pulumi.Input[_builtins.str]:
        """
        The Policy Set Definition type. Possible values are `BuiltIn`, `Custom`, `NotSpecified`, and `Static`. Changing this forces a new Policy Set Definition to be created.
        """
        return pulumi.get(self, "policy_type")

    @policy_type.setter
    def policy_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "policy_type", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of this Policy Set Definition.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The metadata for the Policy Set Definition in JSON format.
        """
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "metadata", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name which should be used for this Policy Set Definition. Changing this forces a new Policy Set Definition to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The parameters for the Policy Set Definition in JSON format. Reducing the number of parameters forces a new resource to be created.
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parameters", value)

    @_builtins.property
    @pulumi.getter(name="policyDefinitionGroups")
    def policy_definition_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionGroupArgs']]]]:
        """
        One or more `policy_definition_group` blocks as defined below.
        """
        return pulumi.get(self, "policy_definition_groups")

    @policy_definition_groups.setter
    def policy_definition_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionGroupArgs']]]]):
        pulumi.set(self, "policy_definition_groups", value)


@pulumi.input_type
class _GroupPolicySetDefinitionState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 management_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 metadata: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parameters: Optional[pulumi.Input[_builtins.str]] = None,
                 policy_definition_groups: Optional[pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionGroupArgs']]]] = None,
                 policy_definition_references: Optional[pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs']]]] = None,
                 policy_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering GroupPolicySetDefinition resources.
        :param pulumi.Input[_builtins.str] description: The description of this Policy Set Definition.
        :param pulumi.Input[_builtins.str] display_name: The display name of this Policy Set Definition.
        :param pulumi.Input[_builtins.str] management_group_id: The ID of the Management Group where this Policy Set Definition should be created. Changing this forces a new Policy Set Definition to be created.
        :param pulumi.Input[_builtins.str] metadata: The metadata for the Policy Set Definition in JSON format.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Policy Set Definition. Changing this forces a new Policy Set Definition to be created.
        :param pulumi.Input[_builtins.str] parameters: The parameters for the Policy Set Definition in JSON format. Reducing the number of parameters forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionGroupArgs']]] policy_definition_groups: One or more `policy_definition_group` blocks as defined below.
        :param pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs']]] policy_definition_references: One or more `policy_definition_reference` blocks as defined below.
        :param pulumi.Input[_builtins.str] policy_type: The Policy Set Definition type. Possible values are `BuiltIn`, `Custom`, `NotSpecified`, and `Static`. Changing this forces a new Policy Set Definition to be created.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if management_group_id is not None:
            pulumi.set(__self__, "management_group_id", management_group_id)
        if metadata is not None:
            pulumi.set(__self__, "metadata", metadata)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if policy_definition_groups is not None:
            pulumi.set(__self__, "policy_definition_groups", policy_definition_groups)
        if policy_definition_references is not None:
            pulumi.set(__self__, "policy_definition_references", policy_definition_references)
        if policy_type is not None:
            pulumi.set(__self__, "policy_type", policy_type)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of this Policy Set Definition.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The display name of this Policy Set Definition.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter(name="managementGroupId")
    def management_group_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Management Group where this Policy Set Definition should be created. Changing this forces a new Policy Set Definition to be created.
        """
        return pulumi.get(self, "management_group_id")

    @management_group_id.setter
    def management_group_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "management_group_id", value)

    @_builtins.property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The metadata for the Policy Set Definition in JSON format.
        """
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "metadata", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name which should be used for this Policy Set Definition. Changing this forces a new Policy Set Definition to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The parameters for the Policy Set Definition in JSON format. Reducing the number of parameters forces a new resource to be created.
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parameters", value)

    @_builtins.property
    @pulumi.getter(name="policyDefinitionGroups")
    def policy_definition_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionGroupArgs']]]]:
        """
        One or more `policy_definition_group` blocks as defined below.
        """
        return pulumi.get(self, "policy_definition_groups")

    @policy_definition_groups.setter
    def policy_definition_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionGroupArgs']]]]):
        pulumi.set(self, "policy_definition_groups", value)

    @_builtins.property
    @pulumi.getter(name="policyDefinitionReferences")
    def policy_definition_references(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs']]]]:
        """
        One or more `policy_definition_reference` blocks as defined below.
        """
        return pulumi.get(self, "policy_definition_references")

    @policy_definition_references.setter
    def policy_definition_references(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs']]]]):
        pulumi.set(self, "policy_definition_references", value)

    @_builtins.property
    @pulumi.getter(name="policyType")
    def policy_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Policy Set Definition type. Possible values are `BuiltIn`, `Custom`, `NotSpecified`, and `Static`. Changing this forces a new Policy Set Definition to be created.
        """
        return pulumi.get(self, "policy_type")

    @policy_type.setter
    def policy_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "policy_type", value)


@pulumi.type_token("azure:management/groupPolicySetDefinition:GroupPolicySetDefinition")
class GroupPolicySetDefinition(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 management_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 metadata: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parameters: Optional[pulumi.Input[_builtins.str]] = None,
                 policy_definition_groups: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupPolicySetDefinitionPolicyDefinitionGroupArgs', 'GroupPolicySetDefinitionPolicyDefinitionGroupArgsDict']]]]] = None,
                 policy_definition_references: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs', 'GroupPolicySetDefinitionPolicyDefinitionReferenceArgsDict']]]]] = None,
                 policy_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages a Policy Set Definition for a Management Group.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.management.Group("example", display_name="Example")
        example_group_policy_set_definition = azure.management.GroupPolicySetDefinition("example",
            name="example",
            policy_type="Custom",
            display_name="Example",
            management_group_id=example.id,
            parameters=\"\"\"   {
               \\"allowedLocations\\": {
                   \\"type\\": \\"Array\\",
                   \\"metadata\\": {
                       \\"description\\": \\"The list of allowed locations for resources.\\",
                       \\"displayName\\": \\"Allowed locations\\",
                       \\"strongType\\": \\"location\\"
                   }
               }
           }
        \"\"\",
            policy_definition_references=[{
                "version": "1.0.*",
                "policy_definition_id": "/providers/Microsoft.Authorization/policyDefinitions/e765b5de-1225-4ba3-bd56-1ac6695af988",
                "parameter_values": \"\"\"   {
             \\"listOfAllowedLocations\\": {\\"value\\": \\"[parameters('allowedLocations')]\\"}
           }
        \"\"\",
            }])
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.Management` - 2025-01-01

        ## Import

        Policy Set Definitions can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:management/groupPolicySetDefinition:GroupPolicySetDefinition example /providers/Microsoft.Management/managementGroups/0000000-0000-0000-0000-000000000000/providers/Microsoft.Authorization/policySetDefinitions/policySetDefinitionName
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The description of this Policy Set Definition.
        :param pulumi.Input[_builtins.str] display_name: The display name of this Policy Set Definition.
        :param pulumi.Input[_builtins.str] management_group_id: The ID of the Management Group where this Policy Set Definition should be created. Changing this forces a new Policy Set Definition to be created.
        :param pulumi.Input[_builtins.str] metadata: The metadata for the Policy Set Definition in JSON format.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Policy Set Definition. Changing this forces a new Policy Set Definition to be created.
        :param pulumi.Input[_builtins.str] parameters: The parameters for the Policy Set Definition in JSON format. Reducing the number of parameters forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GroupPolicySetDefinitionPolicyDefinitionGroupArgs', 'GroupPolicySetDefinitionPolicyDefinitionGroupArgsDict']]]] policy_definition_groups: One or more `policy_definition_group` blocks as defined below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs', 'GroupPolicySetDefinitionPolicyDefinitionReferenceArgsDict']]]] policy_definition_references: One or more `policy_definition_reference` blocks as defined below.
        :param pulumi.Input[_builtins.str] policy_type: The Policy Set Definition type. Possible values are `BuiltIn`, `Custom`, `NotSpecified`, and `Static`. Changing this forces a new Policy Set Definition to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupPolicySetDefinitionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Policy Set Definition for a Management Group.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.management.Group("example", display_name="Example")
        example_group_policy_set_definition = azure.management.GroupPolicySetDefinition("example",
            name="example",
            policy_type="Custom",
            display_name="Example",
            management_group_id=example.id,
            parameters=\"\"\"   {
               \\"allowedLocations\\": {
                   \\"type\\": \\"Array\\",
                   \\"metadata\\": {
                       \\"description\\": \\"The list of allowed locations for resources.\\",
                       \\"displayName\\": \\"Allowed locations\\",
                       \\"strongType\\": \\"location\\"
                   }
               }
           }
        \"\"\",
            policy_definition_references=[{
                "version": "1.0.*",
                "policy_definition_id": "/providers/Microsoft.Authorization/policyDefinitions/e765b5de-1225-4ba3-bd56-1ac6695af988",
                "parameter_values": \"\"\"   {
             \\"listOfAllowedLocations\\": {\\"value\\": \\"[parameters('allowedLocations')]\\"}
           }
        \"\"\",
            }])
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.Management` - 2025-01-01

        ## Import

        Policy Set Definitions can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:management/groupPolicySetDefinition:GroupPolicySetDefinition example /providers/Microsoft.Management/managementGroups/0000000-0000-0000-0000-000000000000/providers/Microsoft.Authorization/policySetDefinitions/policySetDefinitionName
        ```

        :param str resource_name: The name of the resource.
        :param GroupPolicySetDefinitionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupPolicySetDefinitionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 management_group_id: Optional[pulumi.Input[_builtins.str]] = None,
                 metadata: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parameters: Optional[pulumi.Input[_builtins.str]] = None,
                 policy_definition_groups: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupPolicySetDefinitionPolicyDefinitionGroupArgs', 'GroupPolicySetDefinitionPolicyDefinitionGroupArgsDict']]]]] = None,
                 policy_definition_references: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs', 'GroupPolicySetDefinitionPolicyDefinitionReferenceArgsDict']]]]] = None,
                 policy_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupPolicySetDefinitionArgs.__new__(GroupPolicySetDefinitionArgs)

            __props__.__dict__["description"] = description
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            if management_group_id is None and not opts.urn:
                raise TypeError("Missing required property 'management_group_id'")
            __props__.__dict__["management_group_id"] = management_group_id
            __props__.__dict__["metadata"] = metadata
            __props__.__dict__["name"] = name
            __props__.__dict__["parameters"] = parameters
            __props__.__dict__["policy_definition_groups"] = policy_definition_groups
            if policy_definition_references is None and not opts.urn:
                raise TypeError("Missing required property 'policy_definition_references'")
            __props__.__dict__["policy_definition_references"] = policy_definition_references
            if policy_type is None and not opts.urn:
                raise TypeError("Missing required property 'policy_type'")
            __props__.__dict__["policy_type"] = policy_type
        super(GroupPolicySetDefinition, __self__).__init__(
            'azure:management/groupPolicySetDefinition:GroupPolicySetDefinition',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            display_name: Optional[pulumi.Input[_builtins.str]] = None,
            management_group_id: Optional[pulumi.Input[_builtins.str]] = None,
            metadata: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            parameters: Optional[pulumi.Input[_builtins.str]] = None,
            policy_definition_groups: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupPolicySetDefinitionPolicyDefinitionGroupArgs', 'GroupPolicySetDefinitionPolicyDefinitionGroupArgsDict']]]]] = None,
            policy_definition_references: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs', 'GroupPolicySetDefinitionPolicyDefinitionReferenceArgsDict']]]]] = None,
            policy_type: Optional[pulumi.Input[_builtins.str]] = None) -> 'GroupPolicySetDefinition':
        """
        Get an existing GroupPolicySetDefinition resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The description of this Policy Set Definition.
        :param pulumi.Input[_builtins.str] display_name: The display name of this Policy Set Definition.
        :param pulumi.Input[_builtins.str] management_group_id: The ID of the Management Group where this Policy Set Definition should be created. Changing this forces a new Policy Set Definition to be created.
        :param pulumi.Input[_builtins.str] metadata: The metadata for the Policy Set Definition in JSON format.
        :param pulumi.Input[_builtins.str] name: The name which should be used for this Policy Set Definition. Changing this forces a new Policy Set Definition to be created.
        :param pulumi.Input[_builtins.str] parameters: The parameters for the Policy Set Definition in JSON format. Reducing the number of parameters forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GroupPolicySetDefinitionPolicyDefinitionGroupArgs', 'GroupPolicySetDefinitionPolicyDefinitionGroupArgsDict']]]] policy_definition_groups: One or more `policy_definition_group` blocks as defined below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GroupPolicySetDefinitionPolicyDefinitionReferenceArgs', 'GroupPolicySetDefinitionPolicyDefinitionReferenceArgsDict']]]] policy_definition_references: One or more `policy_definition_reference` blocks as defined below.
        :param pulumi.Input[_builtins.str] policy_type: The Policy Set Definition type. Possible values are `BuiltIn`, `Custom`, `NotSpecified`, and `Static`. Changing this forces a new Policy Set Definition to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupPolicySetDefinitionState.__new__(_GroupPolicySetDefinitionState)

        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["management_group_id"] = management_group_id
        __props__.__dict__["metadata"] = metadata
        __props__.__dict__["name"] = name
        __props__.__dict__["parameters"] = parameters
        __props__.__dict__["policy_definition_groups"] = policy_definition_groups
        __props__.__dict__["policy_definition_references"] = policy_definition_references
        __props__.__dict__["policy_type"] = policy_type
        return GroupPolicySetDefinition(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of this Policy Set Definition.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[_builtins.str]:
        """
        The display name of this Policy Set Definition.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter(name="managementGroupId")
    def management_group_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Management Group where this Policy Set Definition should be created. Changing this forces a new Policy Set Definition to be created.
        """
        return pulumi.get(self, "management_group_id")

    @_builtins.property
    @pulumi.getter
    def metadata(self) -> pulumi.Output[_builtins.str]:
        """
        The metadata for the Policy Set Definition in JSON format.
        """
        return pulumi.get(self, "metadata")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name which should be used for this Policy Set Definition. Changing this forces a new Policy Set Definition to be created.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def parameters(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The parameters for the Policy Set Definition in JSON format. Reducing the number of parameters forces a new resource to be created.
        """
        return pulumi.get(self, "parameters")

    @_builtins.property
    @pulumi.getter(name="policyDefinitionGroups")
    def policy_definition_groups(self) -> pulumi.Output[Optional[Sequence['outputs.GroupPolicySetDefinitionPolicyDefinitionGroup']]]:
        """
        One or more `policy_definition_group` blocks as defined below.
        """
        return pulumi.get(self, "policy_definition_groups")

    @_builtins.property
    @pulumi.getter(name="policyDefinitionReferences")
    def policy_definition_references(self) -> pulumi.Output[Sequence['outputs.GroupPolicySetDefinitionPolicyDefinitionReference']]:
        """
        One or more `policy_definition_reference` blocks as defined below.
        """
        return pulumi.get(self, "policy_definition_references")

    @_builtins.property
    @pulumi.getter(name="policyType")
    def policy_type(self) -> pulumi.Output[_builtins.str]:
        """
        The Policy Set Definition type. Possible values are `BuiltIn`, `Custom`, `NotSpecified`, and `Static`. Changing this forces a new Policy Set Definition to be created.
        """
        return pulumi.get(self, "policy_type")

